LocationService class

Constructors

LocationService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getCurrentLocation() Future<LatLng?>
Fetch current user location with timeout and retry logic
openAppSettings() Future<void>
Open app settings for app-specific settings
openLocationSettings() Future<void>
Open app settings for location permission
requestLocationPermission() Future<LocationPermissionStatus>
Check and request location permission