GetGridSection class

Constructors

GetGridSection(W3WRepository repository)

Properties

hashCode int
The hash code for this object.
no setterinherited
repository → W3WRepository
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({required double swLat, required double swLng, required double neLat, required double neLng}) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited