W3WEntity class

Constructors

W3WEntity({required String words, required double lat, required double lng, String? country, String? area, String? language, String? city, String? state, String? address})

Properties

address String?
final
area String?
final
city String?
final
country String?
final
hashCode int
The hash code for this object.
no setterinherited
language String?
final
lat double
final
lng double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final
words String
final

Methods

getCoordinatesString() String
Returns coordinates as formatted string
getDetailedLocation() String
Returns detailed location info
getFormattedAddress() String
Returns formatted address with all available information
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited