W3WGoogleMaps class

The main entry point for the W3W Google Maps package.

Constructors

W3WGoogleMaps()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

provider({required String w3wApiKey, required Widget child, Client? httpClient}) Widget
Initializes the W3W services and provides them via ChangeNotifierProvider.