W3WGoogleMap class
A customizable Google Map widget with integrated What3Words functionality.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- W3WGoogleMap
Constructors
-
W3WGoogleMap({Key? key, required CameraPosition initialCameraPosition, dynamic onW3WSelected(W3WEntity)?, bool showGrid = true, Color gridColor = Colors.blue, double gridOpacity = 0.4, Set<
Marker> markers = const {}, ArgumentCallback<GoogleMapController> ? onMapCreated, ArgumentCallback<LatLng> ? onTap, CameraPositionCallback? onCameraMove}) -
const
Properties
- gridColor → Color
-
The color of the What3Words grid lines.
final
- gridOpacity → double
-
The opacity of the What3Words grid lines.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialCameraPosition → CameraPosition
-
The initial position of the map camera.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
markers
→ Set<
Marker> -
Additional markers to display on the map.
final
- onCameraMove → CameraPositionCallback?
-
Callback when the camera moves.
final
-
onMapCreated
→ ArgumentCallback<
GoogleMapController> ? -
Callback when the map is created.
final
-
onTap
→ ArgumentCallback<
LatLng> ? -
Callback when the map is tapped.
final
- onW3WSelected → dynamic Function(W3WEntity)?
-
Callback when a What3Words address is selected on the map.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showGrid → bool
-
Whether to show the What3Words grid on the map.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< W3WGoogleMap> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited