W3WGridConverter class
Converts What3Words Grid API response to Google Maps Polylines
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
calculateBoundingBox(
LatLng center, double delta) → ({double neLat, double neLng, double swLat, double swLng}) - Calculate bounding box from center and delta
-
convertGridToPolylines(
Map< String, dynamic> gridData, {Color gridColor = Colors.blue, double opacity = 0.4, int lineWidth = 1}) → Set<Polyline> - Convert grid-section API response to polylines
-
isValidBoundingBox(
{required double swLat, required double swLng, required double neLat, required double neLng}) → bool - Validate bounding box coordinates
Constants
- gridIdPrefix → const String