W3WProvider class
Provider class for managing What3Words related state and business logic.
- Inheritance
-
- Object
- ChangeNotifier
- W3WProvider
Constructors
- W3WProvider(ConvertTo3wa convertTo3wa, GetGridSection getGridSection, ConvertToCoordinates convertToCoordinates)
Properties
- convertTo3wa → ConvertTo3wa
-
final
- convertToCoordinates → ConvertToCoordinates
-
final
- errorMessage ↔ String?
-
Error message if the last operation failed.
getter/setter pair
- getGridSection → GetGridSection
-
final
-
gridPolylines
↔ Set<
Polyline> -
Set of polylines representing the W3W grid on the map.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isGridLoading ↔ bool
-
Flag indicating if the grid is currently being fetched.
getter/setter pair
- isLoading ↔ bool
-
Flag indicating if an address lookup is in progress.
getter/setter pair
- result ↔ W3WEntity?
-
The most recent What3Words entity result.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clearGrid(
) → void - Clears the current grid polylines.
-
clearGridCache(
) → void - Clears the grid cache.
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
fetch3wa(
double lat, double lng) → Future< void> - Converts latitude and longitude into a 3-word address.
-
fetchCoordinates(
String words) → Future< void> - Converts a 3-word address into coordinates.
-
fetchW3WGrid(
{required LatLng center, double delta = 0.001}) → Future< void> - Fetch and update W3W grid for the given bounding box.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- GRID_CACHE_DURATION → const Duration